# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.analytics_export_file_format import AnalyticsExportFileFormat
from bitmovin_api_sdk.models.analytics_export_status import AnalyticsExportStatus
from bitmovin_api_sdk.models.analytics_export_task_output_target import AnalyticsExportTaskOutputTarget
from bitmovin_api_sdk.models.analytics_export_type import AnalyticsExportType
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class AnalyticsExportTask(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 start_time=None,
                 end_time=None,
                 name=None,
                 description=None,
                 license_key=None,
                 output=None,
                 progress=None,
                 status=None,
                 started_at=None,
                 finished_at=None,
                 type_=None,
                 columns=None,
                 file_format=None):
        # type: (string_types, datetime, datetime, string_types, string_types, string_types, AnalyticsExportTaskOutputTarget, int, AnalyticsExportStatus, datetime, datetime, AnalyticsExportType, list[string_types], AnalyticsExportFileFormat) -> None
        super(AnalyticsExportTask, self).__init__(id_=id_)

        self._start_time = None
        self._end_time = None
        self._name = None
        self._description = None
        self._license_key = None
        self._output = None
        self._progress = None
        self._status = None
        self._started_at = None
        self._finished_at = None
        self._type = None
        self._columns = list()
        self._file_format = None
        self.discriminator = None

        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if license_key is not None:
            self.license_key = license_key
        if output is not None:
            self.output = output
        if progress is not None:
            self.progress = progress
        if status is not None:
            self.status = status
        if started_at is not None:
            self.started_at = started_at
        if finished_at is not None:
            self.finished_at = finished_at
        if type_ is not None:
            self.type = type_
        if columns is not None:
            self.columns = columns
        if file_format is not None:
            self.file_format = file_format

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AnalyticsExportTask, self), 'openapi_types'):
            types = getattr(super(AnalyticsExportTask, self), 'openapi_types')

        types.update({
            'start_time': 'datetime',
            'end_time': 'datetime',
            'name': 'string_types',
            'description': 'string_types',
            'license_key': 'string_types',
            'output': 'AnalyticsExportTaskOutputTarget',
            'progress': 'int',
            'status': 'AnalyticsExportStatus',
            'started_at': 'datetime',
            'finished_at': 'datetime',
            'type': 'AnalyticsExportType',
            'columns': 'list[string_types]',
            'file_format': 'AnalyticsExportFileFormat'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AnalyticsExportTask, self), 'attribute_map'):
            attributes = getattr(super(AnalyticsExportTask, self), 'attribute_map')

        attributes.update({
            'start_time': 'startTime',
            'end_time': 'endTime',
            'name': 'name',
            'description': 'description',
            'license_key': 'licenseKey',
            'output': 'output',
            'progress': 'progress',
            'status': 'status',
            'started_at': 'startedAt',
            'finished_at': 'finishedAt',
            'type': 'type',
            'columns': 'columns',
            'file_format': 'fileFormat'
        })
        return attributes

    @property
    def start_time(self):
        # type: () -> datetime
        """Gets the start_time of this AnalyticsExportTask.

        Start of timeframe which is exported in UTC format (required)

        :return: The start_time of this AnalyticsExportTask.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        # type: (datetime) -> None
        """Sets the start_time of this AnalyticsExportTask.

        Start of timeframe which is exported in UTC format (required)

        :param start_time: The start_time of this AnalyticsExportTask.
        :type: datetime
        """

        if start_time is not None:
            if not isinstance(start_time, datetime):
                raise TypeError("Invalid type for `start_time`, type has to be `datetime`")

        self._start_time = start_time

    @property
    def end_time(self):
        # type: () -> datetime
        """Gets the end_time of this AnalyticsExportTask.

        End of timeframe which is exported in UTC format (required)

        :return: The end_time of this AnalyticsExportTask.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        # type: (datetime) -> None
        """Sets the end_time of this AnalyticsExportTask.

        End of timeframe which is exported in UTC format (required)

        :param end_time: The end_time of this AnalyticsExportTask.
        :type: datetime
        """

        if end_time is not None:
            if not isinstance(end_time, datetime):
                raise TypeError("Invalid type for `end_time`, type has to be `datetime`")

        self._end_time = end_time

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this AnalyticsExportTask.

        Name of the export task (required)

        :return: The name of this AnalyticsExportTask.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this AnalyticsExportTask.

        Name of the export task (required)

        :param name: The name of this AnalyticsExportTask.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def description(self):
        # type: () -> string_types
        """Gets the description of this AnalyticsExportTask.

        Export task description

        :return: The description of this AnalyticsExportTask.
        :rtype: string_types
        """
        return self._description

    @description.setter
    def description(self, description):
        # type: (string_types) -> None
        """Sets the description of this AnalyticsExportTask.

        Export task description

        :param description: The description of this AnalyticsExportTask.
        :type: string_types
        """

        if description is not None:
            if not isinstance(description, string_types):
                raise TypeError("Invalid type for `description`, type has to be `string_types`")

        self._description = description

    @property
    def license_key(self):
        # type: () -> string_types
        """Gets the license_key of this AnalyticsExportTask.

        License key (required)

        :return: The license_key of this AnalyticsExportTask.
        :rtype: string_types
        """
        return self._license_key

    @license_key.setter
    def license_key(self, license_key):
        # type: (string_types) -> None
        """Sets the license_key of this AnalyticsExportTask.

        License key (required)

        :param license_key: The license_key of this AnalyticsExportTask.
        :type: string_types
        """

        if license_key is not None:
            if not isinstance(license_key, string_types):
                raise TypeError("Invalid type for `license_key`, type has to be `string_types`")

        self._license_key = license_key

    @property
    def output(self):
        # type: () -> AnalyticsExportTaskOutputTarget
        """Gets the output of this AnalyticsExportTask.


        :return: The output of this AnalyticsExportTask.
        :rtype: AnalyticsExportTaskOutputTarget
        """
        return self._output

    @output.setter
    def output(self, output):
        # type: (AnalyticsExportTaskOutputTarget) -> None
        """Sets the output of this AnalyticsExportTask.


        :param output: The output of this AnalyticsExportTask.
        :type: AnalyticsExportTaskOutputTarget
        """

        if output is not None:
            if not isinstance(output, AnalyticsExportTaskOutputTarget):
                raise TypeError("Invalid type for `output`, type has to be `AnalyticsExportTaskOutputTarget`")

        self._output = output

    @property
    def progress(self):
        # type: () -> int
        """Gets the progress of this AnalyticsExportTask.

        Progress of the export task

        :return: The progress of this AnalyticsExportTask.
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        # type: (int) -> None
        """Sets the progress of this AnalyticsExportTask.

        Progress of the export task

        :param progress: The progress of this AnalyticsExportTask.
        :type: int
        """

        if progress is not None:
            if not isinstance(progress, int):
                raise TypeError("Invalid type for `progress`, type has to be `int`")

        self._progress = progress

    @property
    def status(self):
        # type: () -> AnalyticsExportStatus
        """Gets the status of this AnalyticsExportTask.


        :return: The status of this AnalyticsExportTask.
        :rtype: AnalyticsExportStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (AnalyticsExportStatus) -> None
        """Sets the status of this AnalyticsExportTask.


        :param status: The status of this AnalyticsExportTask.
        :type: AnalyticsExportStatus
        """

        if status is not None:
            if not isinstance(status, AnalyticsExportStatus):
                raise TypeError("Invalid type for `status`, type has to be `AnalyticsExportStatus`")

        self._status = status

    @property
    def started_at(self):
        # type: () -> datetime
        """Gets the started_at of this AnalyticsExportTask.

        UTC timestamp when the export task started

        :return: The started_at of this AnalyticsExportTask.
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        # type: (datetime) -> None
        """Sets the started_at of this AnalyticsExportTask.

        UTC timestamp when the export task started

        :param started_at: The started_at of this AnalyticsExportTask.
        :type: datetime
        """

        if started_at is not None:
            if not isinstance(started_at, datetime):
                raise TypeError("Invalid type for `started_at`, type has to be `datetime`")

        self._started_at = started_at

    @property
    def finished_at(self):
        # type: () -> datetime
        """Gets the finished_at of this AnalyticsExportTask.

        UTC timestamp when the export task finished

        :return: The finished_at of this AnalyticsExportTask.
        :rtype: datetime
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        # type: (datetime) -> None
        """Sets the finished_at of this AnalyticsExportTask.

        UTC timestamp when the export task finished

        :param finished_at: The finished_at of this AnalyticsExportTask.
        :type: datetime
        """

        if finished_at is not None:
            if not isinstance(finished_at, datetime):
                raise TypeError("Invalid type for `finished_at`, type has to be `datetime`")

        self._finished_at = finished_at

    @property
    def type(self):
        # type: () -> AnalyticsExportType
        """Gets the type of this AnalyticsExportTask.


        :return: The type of this AnalyticsExportTask.
        :rtype: AnalyticsExportType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (AnalyticsExportType) -> None
        """Sets the type of this AnalyticsExportTask.


        :param type_: The type of this AnalyticsExportTask.
        :type: AnalyticsExportType
        """

        if type_ is not None:
            if not isinstance(type_, AnalyticsExportType):
                raise TypeError("Invalid type for `type`, type has to be `AnalyticsExportType`")

        self._type = type_

    @property
    def columns(self):
        # type: () -> list[string_types]
        """Gets the columns of this AnalyticsExportTask.


        :return: The columns of this AnalyticsExportTask.
        :rtype: list[string_types]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        # type: (list) -> None
        """Sets the columns of this AnalyticsExportTask.


        :param columns: The columns of this AnalyticsExportTask.
        :type: list[string_types]
        """

        if columns is not None:
            if not isinstance(columns, list):
                raise TypeError("Invalid type for `columns`, type has to be `list[string_types]`")

        self._columns = columns

    @property
    def file_format(self):
        # type: () -> AnalyticsExportFileFormat
        """Gets the file_format of this AnalyticsExportTask.

        File format of export file

        :return: The file_format of this AnalyticsExportTask.
        :rtype: AnalyticsExportFileFormat
        """
        return self._file_format

    @file_format.setter
    def file_format(self, file_format):
        # type: (AnalyticsExportFileFormat) -> None
        """Sets the file_format of this AnalyticsExportTask.

        File format of export file

        :param file_format: The file_format of this AnalyticsExportTask.
        :type: AnalyticsExportFileFormat
        """

        if file_format is not None:
            if not isinstance(file_format, AnalyticsExportFileFormat):
                raise TypeError("Invalid type for `file_format`, type has to be `AnalyticsExportFileFormat`")

        self._file_format = file_format

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AnalyticsExportTask, self), "to_dict"):
            result = super(AnalyticsExportTask, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsExportTask):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class TextFilterFont(Enum):
    DEJAVUSANS = "DEJAVUSANS"
    DEJAVUSERIF = "DEJAVUSERIF"
    DEJAVUSANSMONO = "DEJAVUSANSMONO"
    ROBOTOMONO = "ROBOTOMONO"
    ROBOTOBLACK = "ROBOTOBLACK"
    ROBOTO = "ROBOTO"
    ROBOTOCONDENSED = "ROBOTOCONDENSED"



from bitmovin_api_sdk.encoding.configurations.video.h265.h265_api import H265Api
from bitmovin_api_sdk.encoding.configurations.video.h265.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.video.h265.h265_video_configuration_list_query_params import H265VideoConfigurationListQueryParams



import json
import requests

from datetime import datetime, date

from bitmovin_api_sdk.common.bitmovin_api_logger_base import BitmovinApiLoggerBase


class RestClient(object):
    HTTP_HEADERS = {
        'Content-Type': 'application/json',
        'X-Api-Client': 'bitmovin-api-sdk-python',
        'X-Api-Client-Version': '1.132.0'
    }

    DELETE = 'DELETE'
    GET = 'GET'
    PATCH = 'PATCH'
    POST = 'POST'
    PUT = 'PUT'

    API_KEY_HTTP_HEADER_NAME = 'X-Api-Key'
    TENANT_ORG_ID_HTTP_HEADER_NAME = 'X-Tenant-Org-Id'

    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=BitmovinApiLoggerBase()):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(RestClient, self).__init__()

        self.api_key = api_key
        self.tenant_org_id = tenant_org_id
        self.logger = BitmovinApiLoggerBase()

        if logger is not None and isinstance(logger, BitmovinApiLoggerBase) is False:
            raise TypeError("Logger must be subclass of BitmovinApiLoggerBase")
        elif logger is not None and issubclass(type(logger), BitmovinApiLoggerBase) is True:
            self.logger = logger

        if base_url is None or base_url == '':
            self.base_url = 'https://api.bitmovin.com/v1'
        else:
            self.base_url = base_url

        if not self.api_key:
            raise TypeError("api_key has to be set")

        self.http_headers = self.HTTP_HEADERS.copy()
        self.http_headers.update({self.API_KEY_HTTP_HEADER_NAME: self.api_key})
        if self.tenant_org_id is not None and self.tenant_org_id != '':
            self.http_headers.update({self.TENANT_ORG_ID_HTTP_HEADER_NAME: self.tenant_org_id})

    def request(self, method, relative_url, payload=None):
        # type: (str, str, object) -> object

        url = self.urljoin(self.base_url, relative_url)

        if payload is not None and type(payload) != list:
            # Remove none set values
            payload = {k: v for k, v in payload.items() if v is not None}

        self._log_request(method, url, payload)

        if payload is None:
            response = requests.request(method, url, headers=self.http_headers)
        else:
            response = requests.request(method, url, headers=self.http_headers, data=self._serialize(payload))

        response.raise_for_status()

        self.logger.log('RESPONSE: {}'.format(response.text))

        if not response.text:
            return dict()

        return response.json()

    def _serialize(self, object_):
        # type: (object) -> object

        if object_ is None:
            return None
        serialized = json.dumps(object_, sort_keys=True, default=self._default_to_dict)
        self.logger.log('Serialized request object: {}'.format(serialized))
        return serialized

    def _log_request(self, method, url, payload=None):
        # type: (str, str, object) -> None

        log_line = 'REQUEST: {} {}'.format(method, url)
        if payload:
            log_line += '  --> {}'.format(json.dumps(payload, default=self._default_to_dict))
        self.logger.log(log_line)

    @staticmethod
    def urljoin(*args):
        # type: (*object) -> str

        return '/'.join([str(x).strip('/') for x in args])

    @staticmethod
    def _default_to_dict(obj):
        # type: (object) -> object

        if hasattr(obj, 'to_dict'):
            return obj.to_dict()
        if hasattr(obj, '__dict__'):
            return obj.__dict__
        if isinstance(obj, datetime):
            return obj.strftime('%Y-%m-%dT%H:%M:%SZ')
        if isinstance(obj, date):
            return obj.isoformat()



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.color_config import ColorConfig
from bitmovin_api_sdk.models.display_aspect_ratio import DisplayAspectRatio
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.h262_interlace_mode import H262InterlaceMode
from bitmovin_api_sdk.models.h262_preset_configuration import H262PresetConfiguration
from bitmovin_api_sdk.models.level_h262 import LevelH262
from bitmovin_api_sdk.models.pixel_format import PixelFormat
from bitmovin_api_sdk.models.profile_h262 import ProfileH262
from bitmovin_api_sdk.models.video_configuration import VideoConfiguration
import pprint
import six


class H262VideoConfiguration(VideoConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 width=None,
                 height=None,
                 bitrate=None,
                 rate=None,
                 pixel_format=None,
                 color_config=None,
                 sample_aspect_ratio_numerator=None,
                 sample_aspect_ratio_denominator=None,
                 display_aspect_ratio=None,
                 encoding_mode=None,
                 preset_configuration=None,
                 profile=None,
                 bframes=None,
                 max_bitrate=None,
                 min_bitrate=None,
                 bufsize=None,
                 gop_size=None,
                 level=None,
                 interlace_mode=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, int, float, PixelFormat, ColorConfig, int, int, DisplayAspectRatio, EncodingMode, H262PresetConfiguration, ProfileH262, int, int, int, int, int, LevelH262, H262InterlaceMode) -> None
        super(H262VideoConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, width=width, height=height, bitrate=bitrate, rate=rate, pixel_format=pixel_format, color_config=color_config, sample_aspect_ratio_numerator=sample_aspect_ratio_numerator, sample_aspect_ratio_denominator=sample_aspect_ratio_denominator, display_aspect_ratio=display_aspect_ratio, encoding_mode=encoding_mode)

        self._preset_configuration = None
        self._profile = None
        self._bframes = None
        self._max_bitrate = None
        self._min_bitrate = None
        self._bufsize = None
        self._gop_size = None
        self._level = None
        self._interlace_mode = None
        self.discriminator = None

        if preset_configuration is not None:
            self.preset_configuration = preset_configuration
        if profile is not None:
            self.profile = profile
        if bframes is not None:
            self.bframes = bframes
        if max_bitrate is not None:
            self.max_bitrate = max_bitrate
        if min_bitrate is not None:
            self.min_bitrate = min_bitrate
        if bufsize is not None:
            self.bufsize = bufsize
        if gop_size is not None:
            self.gop_size = gop_size
        if level is not None:
            self.level = level
        if interlace_mode is not None:
            self.interlace_mode = interlace_mode

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(H262VideoConfiguration, self), 'openapi_types'):
            types = getattr(super(H262VideoConfiguration, self), 'openapi_types')

        types.update({
            'preset_configuration': 'H262PresetConfiguration',
            'profile': 'ProfileH262',
            'bframes': 'int',
            'max_bitrate': 'int',
            'min_bitrate': 'int',
            'bufsize': 'int',
            'gop_size': 'int',
            'level': 'LevelH262',
            'interlace_mode': 'H262InterlaceMode'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(H262VideoConfiguration, self), 'attribute_map'):
            attributes = getattr(super(H262VideoConfiguration, self), 'attribute_map')

        attributes.update({
            'preset_configuration': 'presetConfiguration',
            'profile': 'profile',
            'bframes': 'bframes',
            'max_bitrate': 'maxBitrate',
            'min_bitrate': 'minBitrate',
            'bufsize': 'bufsize',
            'gop_size': 'gopSize',
            'level': 'level',
            'interlace_mode': 'interlaceMode'
        })
        return attributes

    @property
    def preset_configuration(self):
        # type: () -> H262PresetConfiguration
        """Gets the preset_configuration of this H262VideoConfiguration.

        Use a set of well defined configurations preset to support certain use cases. Can be overwritten with more specific values.

        :return: The preset_configuration of this H262VideoConfiguration.
        :rtype: H262PresetConfiguration
        """
        return self._preset_configuration

    @preset_configuration.setter
    def preset_configuration(self, preset_configuration):
        # type: (H262PresetConfiguration) -> None
        """Sets the preset_configuration of this H262VideoConfiguration.

        Use a set of well defined configurations preset to support certain use cases. Can be overwritten with more specific values.

        :param preset_configuration: The preset_configuration of this H262VideoConfiguration.
        :type: H262PresetConfiguration
        """

        if preset_configuration is not None:
            if not isinstance(preset_configuration, H262PresetConfiguration):
                raise TypeError("Invalid type for `preset_configuration`, type has to be `H262PresetConfiguration`")

        self._preset_configuration = preset_configuration

    @property
    def profile(self):
        # type: () -> ProfileH262
        """Gets the profile of this H262VideoConfiguration.

        When setting a profile, all other settings must not exceed the limits which are defined in the profile. Otherwise, a higher profile may be automatically chosen. (required)

        :return: The profile of this H262VideoConfiguration.
        :rtype: ProfileH262
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        # type: (ProfileH262) -> None
        """Sets the profile of this H262VideoConfiguration.

        When setting a profile, all other settings must not exceed the limits which are defined in the profile. Otherwise, a higher profile may be automatically chosen. (required)

        :param profile: The profile of this H262VideoConfiguration.
        :type: ProfileH262
        """

        if profile is not None:
            if not isinstance(profile, ProfileH262):
                raise TypeError("Invalid type for `profile`, type has to be `ProfileH262`")

        self._profile = profile

    @property
    def bframes(self):
        # type: () -> int
        """Gets the bframes of this H262VideoConfiguration.

        Sets the amount of b frames.

        :return: The bframes of this H262VideoConfiguration.
        :rtype: int
        """
        return self._bframes

    @bframes.setter
    def bframes(self, bframes):
        # type: (int) -> None
        """Sets the bframes of this H262VideoConfiguration.

        Sets the amount of b frames.

        :param bframes: The bframes of this H262VideoConfiguration.
        :type: int
        """

        if bframes is not None:
            if bframes is not None and bframes > 16:
                raise ValueError("Invalid value for `bframes`, must be a value less than or equal to `16`")
            if bframes is not None and bframes < 0:
                raise ValueError("Invalid value for `bframes`, must be a value greater than or equal to `0`")
            if not isinstance(bframes, int):
                raise TypeError("Invalid type for `bframes`, type has to be `int`")

        self._bframes = bframes

    @property
    def max_bitrate(self):
        # type: () -> int
        """Gets the max_bitrate of this H262VideoConfiguration.

        Maximum Bitrate

        :return: The max_bitrate of this H262VideoConfiguration.
        :rtype: int
        """
        return self._max_bitrate

    @max_bitrate.setter
    def max_bitrate(self, max_bitrate):
        # type: (int) -> None
        """Sets the max_bitrate of this H262VideoConfiguration.

        Maximum Bitrate

        :param max_bitrate: The max_bitrate of this H262VideoConfiguration.
        :type: int
        """

        if max_bitrate is not None:
            if not isinstance(max_bitrate, int):
                raise TypeError("Invalid type for `max_bitrate`, type has to be `int`")

        self._max_bitrate = max_bitrate

    @property
    def min_bitrate(self):
        # type: () -> int
        """Gets the min_bitrate of this H262VideoConfiguration.

        Minimum Bitrate

        :return: The min_bitrate of this H262VideoConfiguration.
        :rtype: int
        """
        return self._min_bitrate

    @min_bitrate.setter
    def min_bitrate(self, min_bitrate):
        # type: (int) -> None
        """Sets the min_bitrate of this H262VideoConfiguration.

        Minimum Bitrate

        :param min_bitrate: The min_bitrate of this H262VideoConfiguration.
        :type: int
        """

        if min_bitrate is not None:
            if not isinstance(min_bitrate, int):
                raise TypeError("Invalid type for `min_bitrate`, type has to be `int`")

        self._min_bitrate = min_bitrate

    @property
    def bufsize(self):
        # type: () -> int
        """Gets the bufsize of this H262VideoConfiguration.

        Playback device buffer size

        :return: The bufsize of this H262VideoConfiguration.
        :rtype: int
        """
        return self._bufsize

    @bufsize.setter
    def bufsize(self, bufsize):
        # type: (int) -> None
        """Sets the bufsize of this H262VideoConfiguration.

        Playback device buffer size

        :param bufsize: The bufsize of this H262VideoConfiguration.
        :type: int
        """

        if bufsize is not None:
            if not isinstance(bufsize, int):
                raise TypeError("Invalid type for `bufsize`, type has to be `int`")

        self._bufsize = bufsize

    @property
    def gop_size(self):
        # type: () -> int
        """Gets the gop_size of this H262VideoConfiguration.

        Minimum GOP length, the minimum distance between I-frames

        :return: The gop_size of this H262VideoConfiguration.
        :rtype: int
        """
        return self._gop_size

    @gop_size.setter
    def gop_size(self, gop_size):
        # type: (int) -> None
        """Sets the gop_size of this H262VideoConfiguration.

        Minimum GOP length, the minimum distance between I-frames

        :param gop_size: The gop_size of this H262VideoConfiguration.
        :type: int
        """

        if gop_size is not None:
            if not isinstance(gop_size, int):
                raise TypeError("Invalid type for `gop_size`, type has to be `int`")

        self._gop_size = gop_size

    @property
    def level(self):
        # type: () -> LevelH262
        """Gets the level of this H262VideoConfiguration.

        Specified set of constraints that indicate a degree of required decoder performance for a profile

        :return: The level of this H262VideoConfiguration.
        :rtype: LevelH262
        """
        return self._level

    @level.setter
    def level(self, level):
        # type: (LevelH262) -> None
        """Sets the level of this H262VideoConfiguration.

        Specified set of constraints that indicate a degree of required decoder performance for a profile

        :param level: The level of this H262VideoConfiguration.
        :type: LevelH262
        """

        if level is not None:
            if not isinstance(level, LevelH262):
                raise TypeError("Invalid type for `level`, type has to be `LevelH262`")

        self._level = level

    @property
    def interlace_mode(self):
        # type: () -> H262InterlaceMode
        """Gets the interlace_mode of this H262VideoConfiguration.

        Using TOP_FIELD_FIRST or BOTTOM_FIELD_FIRST will output interlaced video

        :return: The interlace_mode of this H262VideoConfiguration.
        :rtype: H262InterlaceMode
        """
        return self._interlace_mode

    @interlace_mode.setter
    def interlace_mode(self, interlace_mode):
        # type: (H262InterlaceMode) -> None
        """Sets the interlace_mode of this H262VideoConfiguration.

        Using TOP_FIELD_FIRST or BOTTOM_FIELD_FIRST will output interlaced video

        :param interlace_mode: The interlace_mode of this H262VideoConfiguration.
        :type: H262InterlaceMode
        """

        if interlace_mode is not None:
            if not isinstance(interlace_mode, H262InterlaceMode):
                raise TypeError("Invalid type for `interlace_mode`, type has to be `H262InterlaceMode`")

        self._interlace_mode = interlace_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(H262VideoConfiguration, self), "to_dict"):
            result = super(H262VideoConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, H262VideoConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.subtitle_configuration import SubtitleConfiguration
from bitmovin_api_sdk.models.web_vtt_cue_identifier_policy import WebVttCueIdentifierPolicy
from bitmovin_api_sdk.models.web_vtt_styling import WebVttStyling
import pprint
import six


class WebVttConfiguration(SubtitleConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 append_optional_zero_hour=None,
                 ignore_region=None,
                 cue_identifier_policy=None,
                 styling=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, bool, bool, WebVttCueIdentifierPolicy, WebVttStyling) -> None
        super(WebVttConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._append_optional_zero_hour = None
        self._ignore_region = None
        self._cue_identifier_policy = None
        self._styling = None
        self.discriminator = None

        if append_optional_zero_hour is not None:
            self.append_optional_zero_hour = append_optional_zero_hour
        if ignore_region is not None:
            self.ignore_region = ignore_region
        if cue_identifier_policy is not None:
            self.cue_identifier_policy = cue_identifier_policy
        if styling is not None:
            self.styling = styling

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(WebVttConfiguration, self), 'openapi_types'):
            types = getattr(super(WebVttConfiguration, self), 'openapi_types')

        types.update({
            'append_optional_zero_hour': 'bool',
            'ignore_region': 'bool',
            'cue_identifier_policy': 'WebVttCueIdentifierPolicy',
            'styling': 'WebVttStyling'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(WebVttConfiguration, self), 'attribute_map'):
            attributes = getattr(super(WebVttConfiguration, self), 'attribute_map')

        attributes.update({
            'append_optional_zero_hour': 'appendOptionalZeroHour',
            'ignore_region': 'ignoreRegion',
            'cue_identifier_policy': 'cueIdentifierPolicy',
            'styling': 'styling'
        })
        return attributes

    @property
    def append_optional_zero_hour(self):
        # type: () -> bool
        """Gets the append_optional_zero_hour of this WebVttConfiguration.

        If set to true, the hours section on webvtt timestamp values will explicitely have zeroes instead of being omitted for values where hours = 0.

        :return: The append_optional_zero_hour of this WebVttConfiguration.
        :rtype: bool
        """
        return self._append_optional_zero_hour

    @append_optional_zero_hour.setter
    def append_optional_zero_hour(self, append_optional_zero_hour):
        # type: (bool) -> None
        """Sets the append_optional_zero_hour of this WebVttConfiguration.

        If set to true, the hours section on webvtt timestamp values will explicitely have zeroes instead of being omitted for values where hours = 0.

        :param append_optional_zero_hour: The append_optional_zero_hour of this WebVttConfiguration.
        :type: bool
        """

        if append_optional_zero_hour is not None:
            if not isinstance(append_optional_zero_hour, bool):
                raise TypeError("Invalid type for `append_optional_zero_hour`, type has to be `bool`")

        self._append_optional_zero_hour = append_optional_zero_hour

    @property
    def ignore_region(self):
        # type: () -> bool
        """Gets the ignore_region of this WebVttConfiguration.

        If set to true, the region information of the resulting webvtt file will be omitted. Defaults to false.

        :return: The ignore_region of this WebVttConfiguration.
        :rtype: bool
        """
        return self._ignore_region

    @ignore_region.setter
    def ignore_region(self, ignore_region):
        # type: (bool) -> None
        """Sets the ignore_region of this WebVttConfiguration.

        If set to true, the region information of the resulting webvtt file will be omitted. Defaults to false.

        :param ignore_region: The ignore_region of this WebVttConfiguration.
        :type: bool
        """

        if ignore_region is not None:
            if not isinstance(ignore_region, bool):
                raise TypeError("Invalid type for `ignore_region`, type has to be `bool`")

        self._ignore_region = ignore_region

    @property
    def cue_identifier_policy(self):
        # type: () -> WebVttCueIdentifierPolicy
        """Gets the cue_identifier_policy of this WebVttConfiguration.


        :return: The cue_identifier_policy of this WebVttConfiguration.
        :rtype: WebVttCueIdentifierPolicy
        """
        return self._cue_identifier_policy

    @cue_identifier_policy.setter
    def cue_identifier_policy(self, cue_identifier_policy):
        # type: (WebVttCueIdentifierPolicy) -> None
        """Sets the cue_identifier_policy of this WebVttConfiguration.


        :param cue_identifier_policy: The cue_identifier_policy of this WebVttConfiguration.
        :type: WebVttCueIdentifierPolicy
        """

        if cue_identifier_policy is not None:
            if not isinstance(cue_identifier_policy, WebVttCueIdentifierPolicy):
                raise TypeError("Invalid type for `cue_identifier_policy`, type has to be `WebVttCueIdentifierPolicy`")

        self._cue_identifier_policy = cue_identifier_policy

    @property
    def styling(self):
        # type: () -> WebVttStyling
        """Gets the styling of this WebVttConfiguration.


        :return: The styling of this WebVttConfiguration.
        :rtype: WebVttStyling
        """
        return self._styling

    @styling.setter
    def styling(self, styling):
        # type: (WebVttStyling) -> None
        """Sets the styling of this WebVttConfiguration.


        :param styling: The styling of this WebVttConfiguration.
        :type: WebVttStyling
        """

        if styling is not None:
            if not isinstance(styling, WebVttStyling):
                raise TypeError("Invalid type for `styling`, type has to be `WebVttStyling`")

        self._styling = styling

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(WebVttConfiguration, self), "to_dict"):
            result = super(WebVttConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebVttConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.message_type import MessageType
import pprint
import six


class Message(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 type_=None,
                 text=None,
                 field=None,
                 links=None,
                 more=None,
                 date_=None):
        # type: (string_types, MessageType, string_types, string_types, list[Link], object, datetime) -> None
        super(Message, self).__init__(id_=id_)

        self._type = None
        self._text = None
        self._field = None
        self._links = list()
        self._more = None
        self._date = None
        self.discriminator = None

        if type_ is not None:
            self.type = type_
        if text is not None:
            self.text = text
        if field is not None:
            self.field = field
        if links is not None:
            self.links = links
        if more is not None:
            self.more = more
        if date_ is not None:
            self.date = date_

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Message, self), 'openapi_types'):
            types = getattr(super(Message, self), 'openapi_types')

        types.update({
            'type': 'MessageType',
            'text': 'string_types',
            'field': 'string_types',
            'links': 'list[Link]',
            'more': 'object',
            'date': 'datetime'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Message, self), 'attribute_map'):
            attributes = getattr(super(Message, self), 'attribute_map')

        attributes.update({
            'type': 'type',
            'text': 'text',
            'field': 'field',
            'links': 'links',
            'more': 'more',
            'date': 'date'
        })
        return attributes

    @property
    def type(self):
        # type: () -> MessageType
        """Gets the type of this Message.

        Message type giving a hint on the importance of the message (log level) (required)

        :return: The type of this Message.
        :rtype: MessageType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (MessageType) -> None
        """Sets the type of this Message.

        Message type giving a hint on the importance of the message (log level) (required)

        :param type_: The type of this Message.
        :type: MessageType
        """

        if type_ is not None:
            if not isinstance(type_, MessageType):
                raise TypeError("Invalid type for `type`, type has to be `MessageType`")

        self._type = type_

    @property
    def text(self):
        # type: () -> string_types
        """Gets the text of this Message.

        Message text (required)

        :return: The text of this Message.
        :rtype: string_types
        """
        return self._text

    @text.setter
    def text(self, text):
        # type: (string_types) -> None
        """Sets the text of this Message.

        Message text (required)

        :param text: The text of this Message.
        :type: string_types
        """

        if text is not None:
            if not isinstance(text, string_types):
                raise TypeError("Invalid type for `text`, type has to be `string_types`")

        self._text = text

    @property
    def field(self):
        # type: () -> string_types
        """Gets the field of this Message.

        Name of the field to which the message is referring to

        :return: The field of this Message.
        :rtype: string_types
        """
        return self._field

    @field.setter
    def field(self, field):
        # type: (string_types) -> None
        """Sets the field of this Message.

        Name of the field to which the message is referring to

        :param field: The field of this Message.
        :type: string_types
        """

        if field is not None:
            if not isinstance(field, string_types):
                raise TypeError("Invalid type for `field`, type has to be `string_types`")

        self._field = field

    @property
    def links(self):
        # type: () -> list[Link]
        """Gets the links of this Message.

        collection of links to webpages containing further information on the topic

        :return: The links of this Message.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        # type: (list) -> None
        """Sets the links of this Message.

        collection of links to webpages containing further information on the topic

        :param links: The links of this Message.
        :type: list[Link]
        """

        if links is not None:
            if not isinstance(links, list):
                raise TypeError("Invalid type for `links`, type has to be `list[Link]`")

        self._links = links

    @property
    def more(self):
        # type: () -> object
        """Gets the more of this Message.

        Service-specific information

        :return: The more of this Message.
        :rtype: object
        """
        return self._more

    @more.setter
    def more(self, more):
        # type: (object) -> None
        """Sets the more of this Message.

        Service-specific information

        :param more: The more of this Message.
        :type: object
        """

        if more is not None:
            if not isinstance(more, object):
                raise TypeError("Invalid type for `more`, type has to be `object`")

        self._more = more

    @property
    def date(self):
        # type: () -> datetime
        """Gets the date of this Message.

        Timestamp when the message occured

        :return: The date of this Message.
        :rtype: datetime
        """
        return self._date

    @date.setter
    def date(self, date_):
        # type: (datetime) -> None
        """Sets the date of this Message.

        Timestamp when the message occured

        :param date_: The date of this Message.
        :type: datetime
        """

        if date_ is not None:
            if not isinstance(date_, datetime):
                raise TypeError("Invalid type for `date`, type has to be `datetime`")

        self._date = date_

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Message, self), "to_dict"):
            result = super(Message, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Message):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.local_output import LocalOutput
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.outputs.local.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.local.local_output_list_query_params import LocalOutputListQueryParams


class LocalApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LocalApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, local_output, **kwargs):
        # type: (LocalOutput, dict) -> LocalOutput
        """Create Local Output

        :param local_output: The Local output to be created
        :type local_output: LocalOutput, required
        :return: Local output
        :rtype: LocalOutput
        """

        return self.api_client.post(
            '/encoding/outputs/local',
            local_output,
            type=LocalOutput,
            **kwargs
        )

    def delete(self, output_id, **kwargs):
        # type: (string_types, dict) -> LocalOutput
        """Delete Local Output

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Id of the output
        :rtype: LocalOutput
        """

        return self.api_client.delete(
            '/encoding/outputs/local/{output_id}',
            path_params={'output_id': output_id},
            type=LocalOutput,
            **kwargs
        )

    def get(self, output_id, **kwargs):
        # type: (string_types, dict) -> LocalOutput
        """Local Output Details

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Local output details
        :rtype: LocalOutput
        """

        return self.api_client.get(
            '/encoding/outputs/local/{output_id}',
            path_params={'output_id': output_id},
            type=LocalOutput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (LocalOutputListQueryParams, dict) -> LocalOutput
        """List Local Outputs

        :param query_params: Query parameters
        :type query_params: LocalOutputListQueryParams
        :return: List of Local outputs
        :rtype: LocalOutput
        """

        return self.api_client.get(
            '/encoding/outputs/local',
            query_params=query_params,
            pagination_response=True,
            type=LocalOutput,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.aes_encryption_drm import AesEncryptionDrm
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.muxings.ts.drm.aes.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.ts.drm.aes.aes_encryption_drm_list_query_params import AesEncryptionDrmListQueryParams


class AesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, muxing_id, aes_encryption_drm, **kwargs):
        # type: (string_types, string_types, AesEncryptionDrm, dict) -> AesEncryptionDrm
        """Add AES encryption configuration to a TS muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the TS muxing.
        :type muxing_id: string_types, required
        :param aes_encryption_drm: The AES encryption configuration to be created
        :type aes_encryption_drm: AesEncryptionDrm, required
        :return: AESEncryption details
        :rtype: AesEncryptionDrm
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/muxings/ts/{muxing_id}/drm/aes',
            aes_encryption_drm,
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=AesEncryptionDrm,
            **kwargs
        )

    def delete(self, encoding_id, muxing_id, drm_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete AES encryption configuration from a TS muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the TS muxing.
        :type muxing_id: string_types, required
        :param drm_id: Id of the PlayReady DRM configuration.
        :type drm_id: string_types, required
        :return: Id of the AES encryption configuration.
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/muxings/ts/{muxing_id}/drm/aes/{drm_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'drm_id': drm_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, muxing_id, drm_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> AesEncryptionDrm
        """AES encryption Details of a TS muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the TS muxing.
        :type muxing_id: string_types, required
        :param drm_id: Id of the AES encryption configuration.
        :type drm_id: string_types, required
        :return: AESEncryption details
        :rtype: AesEncryptionDrm
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/ts/{muxing_id}/drm/aes/{drm_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'drm_id': drm_id},
            type=AesEncryptionDrm,
            **kwargs
        )

    def list(self, encoding_id, muxing_id, query_params=None, **kwargs):
        # type: (string_types, string_types, AesEncryptionDrmListQueryParams, dict) -> AesEncryptionDrm
        """List AES encryption configurations of a TS muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the TS muxing.
        :type muxing_id: string_types, required
        :param query_params: Query parameters
        :type query_params: AesEncryptionDrmListQueryParams
        :return: List of AES encryption configurations
        :rtype: AesEncryptionDrm
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/ts/{muxing_id}/drm/aes',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            query_params=query_params,
            pagination_response=True,
            type=AesEncryptionDrm,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class H264InterlaceMode(Enum):
    NONE = "NONE"
    TOP_FIELD_FIRST = "TOP_FIELD_FIRST"
    BOTTOM_FIELD_FIRST = "BOTTOM_FIELD_FIRST"



from bitmovin_api_sdk.encoding.infrastructure.static_ips.static_ips_api import StaticIpsApi
from bitmovin_api_sdk.encoding.infrastructure.static_ips.static_ip_list_query_params import StaticIpListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.channels_attribute_for_audio import ChannelsAttributeForAudio
from bitmovin_api_sdk.models.hls_target_duration_rounding_mode import HlsTargetDurationRoundingMode
from bitmovin_api_sdk.models.hls_version import HlsVersion
from bitmovin_api_sdk.models.manifest import Manifest
from bitmovin_api_sdk.models.manifest_type import ManifestType
from bitmovin_api_sdk.models.status import Status
import pprint
import six


class HlsManifest(Manifest):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 type_=None,
                 outputs=None,
                 status=None,
                 manifest_name=None,
                 hls_media_playlist_version=None,
                 hls_master_playlist_version=None,
                 channels_attribute_for_audio=None,
                 target_duration_rounding_mode=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, ManifestType, list[EncodingOutput], Status, string_types, HlsVersion, HlsVersion, ChannelsAttributeForAudio, HlsTargetDurationRoundingMode) -> None
        super(HlsManifest, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, type_=type_, outputs=outputs, status=status)

        self._manifest_name = None
        self._hls_media_playlist_version = None
        self._hls_master_playlist_version = None
        self._channels_attribute_for_audio = None
        self._target_duration_rounding_mode = None
        self.discriminator = None

        if manifest_name is not None:
            self.manifest_name = manifest_name
        if hls_media_playlist_version is not None:
            self.hls_media_playlist_version = hls_media_playlist_version
        if hls_master_playlist_version is not None:
            self.hls_master_playlist_version = hls_master_playlist_version
        if channels_attribute_for_audio is not None:
            self.channels_attribute_for_audio = channels_attribute_for_audio
        if target_duration_rounding_mode is not None:
            self.target_duration_rounding_mode = target_duration_rounding_mode

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(HlsManifest, self), 'openapi_types'):
            types = getattr(super(HlsManifest, self), 'openapi_types')

        types.update({
            'manifest_name': 'string_types',
            'hls_media_playlist_version': 'HlsVersion',
            'hls_master_playlist_version': 'HlsVersion',
            'channels_attribute_for_audio': 'ChannelsAttributeForAudio',
            'target_duration_rounding_mode': 'HlsTargetDurationRoundingMode'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(HlsManifest, self), 'attribute_map'):
            attributes = getattr(super(HlsManifest, self), 'attribute_map')

        attributes.update({
            'manifest_name': 'manifestName',
            'hls_media_playlist_version': 'hlsMediaPlaylistVersion',
            'hls_master_playlist_version': 'hlsMasterPlaylistVersion',
            'channels_attribute_for_audio': 'channelsAttributeForAudio',
            'target_duration_rounding_mode': 'targetDurationRoundingMode'
        })
        return attributes

    @property
    def manifest_name(self):
        # type: () -> string_types
        """Gets the manifest_name of this HlsManifest.

        The filename of your manifest. If this is not set, the `name` is used as output file name. Either one of `name` or `manifestName` is required. Be aware that spaces will be replaced with underlines (`_`) on the output.

        :return: The manifest_name of this HlsManifest.
        :rtype: string_types
        """
        return self._manifest_name

    @manifest_name.setter
    def manifest_name(self, manifest_name):
        # type: (string_types) -> None
        """Sets the manifest_name of this HlsManifest.

        The filename of your manifest. If this is not set, the `name` is used as output file name. Either one of `name` or `manifestName` is required. Be aware that spaces will be replaced with underlines (`_`) on the output.

        :param manifest_name: The manifest_name of this HlsManifest.
        :type: string_types
        """

        if manifest_name is not None:
            if not isinstance(manifest_name, string_types):
                raise TypeError("Invalid type for `manifest_name`, type has to be `string_types`")

        self._manifest_name = manifest_name

    @property
    def hls_media_playlist_version(self):
        # type: () -> HlsVersion
        """Gets the hls_media_playlist_version of this HlsManifest.

        If this is set, the EXT-X-VERSION tags of the Media Playlists are set to the provided version

        :return: The hls_media_playlist_version of this HlsManifest.
        :rtype: HlsVersion
        """
        return self._hls_media_playlist_version

    @hls_media_playlist_version.setter
    def hls_media_playlist_version(self, hls_media_playlist_version):
        # type: (HlsVersion) -> None
        """Sets the hls_media_playlist_version of this HlsManifest.

        If this is set, the EXT-X-VERSION tags of the Media Playlists are set to the provided version

        :param hls_media_playlist_version: The hls_media_playlist_version of this HlsManifest.
        :type: HlsVersion
        """

        if hls_media_playlist_version is not None:
            if not isinstance(hls_media_playlist_version, HlsVersion):
                raise TypeError("Invalid type for `hls_media_playlist_version`, type has to be `HlsVersion`")

        self._hls_media_playlist_version = hls_media_playlist_version

    @property
    def hls_master_playlist_version(self):
        # type: () -> HlsVersion
        """Gets the hls_master_playlist_version of this HlsManifest.

        If this is set, the EXT-X-VERSION tag of the Master Playlist is set to the provided version

        :return: The hls_master_playlist_version of this HlsManifest.
        :rtype: HlsVersion
        """
        return self._hls_master_playlist_version

    @hls_master_playlist_version.setter
    def hls_master_playlist_version(self, hls_master_playlist_version):
        # type: (HlsVersion) -> None
        """Sets the hls_master_playlist_version of this HlsManifest.

        If this is set, the EXT-X-VERSION tag of the Master Playlist is set to the provided version

        :param hls_master_playlist_version: The hls_master_playlist_version of this HlsManifest.
        :type: HlsVersion
        """

        if hls_master_playlist_version is not None:
            if not isinstance(hls_master_playlist_version, HlsVersion):
                raise TypeError("Invalid type for `hls_master_playlist_version`, type has to be `HlsVersion`")

        self._hls_master_playlist_version = hls_master_playlist_version

    @property
    def channels_attribute_for_audio(self):
        # type: () -> ChannelsAttributeForAudio
        """Gets the channels_attribute_for_audio of this HlsManifest.

        Controls the behaviour of the CHANNELS attribute for the EXT-X-VERSION tag

        :return: The channels_attribute_for_audio of this HlsManifest.
        :rtype: ChannelsAttributeForAudio
        """
        return self._channels_attribute_for_audio

    @channels_attribute_for_audio.setter
    def channels_attribute_for_audio(self, channels_attribute_for_audio):
        # type: (ChannelsAttributeForAudio) -> None
        """Sets the channels_attribute_for_audio of this HlsManifest.

        Controls the behaviour of the CHANNELS attribute for the EXT-X-VERSION tag

        :param channels_attribute_for_audio: The channels_attribute_for_audio of this HlsManifest.
        :type: ChannelsAttributeForAudio
        """

        if channels_attribute_for_audio is not None:
            if not isinstance(channels_attribute_for_audio, ChannelsAttributeForAudio):
                raise TypeError("Invalid type for `channels_attribute_for_audio`, type has to be `ChannelsAttributeForAudio`")

        self._channels_attribute_for_audio = channels_attribute_for_audio

    @property
    def target_duration_rounding_mode(self):
        # type: () -> HlsTargetDurationRoundingMode
        """Gets the target_duration_rounding_mode of this HlsManifest.

        The rounding applied to target duration. Two possible rouding modes exist: NORMAL_ROUNDING, when the target duration is rounded to the nearest integer, or UPWARDS_ROUNDING, when the target duration is rounded to the highest integer. 

        :return: The target_duration_rounding_mode of this HlsManifest.
        :rtype: HlsTargetDurationRoundingMode
        """
        return self._target_duration_rounding_mode

    @target_duration_rounding_mode.setter
    def target_duration_rounding_mode(self, target_duration_rounding_mode):
        # type: (HlsTargetDurationRoundingMode) -> None
        """Sets the target_duration_rounding_mode of this HlsManifest.

        The rounding applied to target duration. Two possible rouding modes exist: NORMAL_ROUNDING, when the target duration is rounded to the nearest integer, or UPWARDS_ROUNDING, when the target duration is rounded to the highest integer. 

        :param target_duration_rounding_mode: The target_duration_rounding_mode of this HlsManifest.
        :type: HlsTargetDurationRoundingMode
        """

        if target_duration_rounding_mode is not None:
            if not isinstance(target_duration_rounding_mode, HlsTargetDurationRoundingMode):
                raise TypeError("Invalid type for `target_duration_rounding_mode`, type has to be `HlsTargetDurationRoundingMode`")

        self._target_duration_rounding_mode = target_duration_rounding_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(HlsManifest, self), "to_dict"):
            result = super(HlsManifest, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HlsManifest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.outputs.akamai_netstorage.akamai_netstorage_api import AkamaiNetstorageApi
from bitmovin_api_sdk.encoding.outputs.akamai_netstorage.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.akamai_netstorage.akamai_net_storage_output_list_query_params import AkamaiNetStorageOutputListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PlayerThirdPartyLicensingErrorAction(Enum):
    ALLOW = "ALLOW"
    DENY = "DENY"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.srt_input import SrtInput
from bitmovin_api_sdk.encoding.inputs.srt.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.srt.srt_input_list_query_params import SrtInputListQueryParams


class SrtApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SrtApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, srt_input, **kwargs):
        # type: (SrtInput, dict) -> SrtInput
        """Create SRT input

        :param srt_input: The SrtInput to be created
        :type srt_input: SrtInput, required
        :return: SRT input
        :rtype: SrtInput
        """

        return self.api_client.post(
            '/encoding/inputs/srt',
            srt_input,
            type=SrtInput,
            **kwargs
        )

    def delete(self, input_id, **kwargs):
        # type: (string_types, dict) -> SrtInput
        """Delete SRT input

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Id of the input
        :rtype: SrtInput
        """

        return self.api_client.delete(
            '/encoding/inputs/srt/{input_id}',
            path_params={'input_id': input_id},
            type=SrtInput,
            **kwargs
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> SrtInput
        """SRT Input Details

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: SRT input
        :rtype: SrtInput
        """

        return self.api_client.get(
            '/encoding/inputs/srt/{input_id}',
            path_params={'input_id': input_id},
            type=SrtInput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (SrtInputListQueryParams, dict) -> SrtInput
        """List SRT inputs

        :param query_params: Query parameters
        :type query_params: SrtInputListQueryParams
        :return: List of SRT inputs
        :rtype: SrtInput
        """

        return self.api_client.get(
            '/encoding/inputs/srt',
            query_params=query_params,
            pagination_response=True,
            type=SrtInput,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.encoding_stream_input_details import EncodingStreamInputDetails
from bitmovin_api_sdk.models.stream_selection_mode import StreamSelectionMode
import pprint
import six


class StreamInput(object):
    @poscheck_model
    def __init__(self,
                 input_id=None,
                 input_path=None,
                 selection_mode=None,
                 position=None,
                 input_stream_id=None,
                 analysis_details=None):
        # type: (string_types, string_types, StreamSelectionMode, int, string_types, EncodingStreamInputDetails) -> None

        self._input_id = None
        self._input_path = None
        self._selection_mode = None
        self._position = None
        self._input_stream_id = None
        self._analysis_details = None
        self.discriminator = None

        if input_id is not None:
            self.input_id = input_id
        if input_path is not None:
            self.input_path = input_path
        if selection_mode is not None:
            self.selection_mode = selection_mode
        if position is not None:
            self.position = position
        if input_stream_id is not None:
            self.input_stream_id = input_stream_id
        if analysis_details is not None:
            self.analysis_details = analysis_details

    @property
    def openapi_types(self):
        types = {
            'input_id': 'string_types',
            'input_path': 'string_types',
            'selection_mode': 'StreamSelectionMode',
            'position': 'int',
            'input_stream_id': 'string_types',
            'analysis_details': 'EncodingStreamInputDetails'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'input_id': 'inputId',
            'input_path': 'inputPath',
            'selection_mode': 'selectionMode',
            'position': 'position',
            'input_stream_id': 'inputStreamId',
            'analysis_details': 'analysisDetails'
        }
        return attributes

    @property
    def input_id(self):
        # type: () -> string_types
        """Gets the input_id of this StreamInput.

        ID of an Input resource defining the input storage. Required if 'inputStreamId' is not set.

        :return: The input_id of this StreamInput.
        :rtype: string_types
        """
        return self._input_id

    @input_id.setter
    def input_id(self, input_id):
        # type: (string_types) -> None
        """Sets the input_id of this StreamInput.

        ID of an Input resource defining the input storage. Required if 'inputStreamId' is not set.

        :param input_id: The input_id of this StreamInput.
        :type: string_types
        """

        if input_id is not None:
            if not isinstance(input_id, string_types):
                raise TypeError("Invalid type for `input_id`, type has to be `string_types`")

        self._input_id = input_id

    @property
    def input_path(self):
        # type: () -> string_types
        """Gets the input_path of this StreamInput.

        Path to an input media file. Required if 'inputStreamId' is not set.

        :return: The input_path of this StreamInput.
        :rtype: string_types
        """
        return self._input_path

    @input_path.setter
    def input_path(self, input_path):
        # type: (string_types) -> None
        """Sets the input_path of this StreamInput.

        Path to an input media file. Required if 'inputStreamId' is not set.

        :param input_path: The input_path of this StreamInput.
        :type: string_types
        """

        if input_path is not None:
            if not isinstance(input_path, string_types):
                raise TypeError("Invalid type for `input_path`, type has to be `string_types`")

        self._input_path = input_path

    @property
    def selection_mode(self):
        # type: () -> StreamSelectionMode
        """Gets the selection_mode of this StreamInput.

        Specifies the strategy for selecting a stream from the input file. Must not be set when 'inputStreamId' is set.

        :return: The selection_mode of this StreamInput.
        :rtype: StreamSelectionMode
        """
        return self._selection_mode

    @selection_mode.setter
    def selection_mode(self, selection_mode):
        # type: (StreamSelectionMode) -> None
        """Sets the selection_mode of this StreamInput.

        Specifies the strategy for selecting a stream from the input file. Must not be set when 'inputStreamId' is set.

        :param selection_mode: The selection_mode of this StreamInput.
        :type: StreamSelectionMode
        """

        if selection_mode is not None:
            if not isinstance(selection_mode, StreamSelectionMode):
                raise TypeError("Invalid type for `selection_mode`, type has to be `StreamSelectionMode`")

        self._selection_mode = selection_mode

    @property
    def position(self):
        # type: () -> int
        """Gets the position of this StreamInput.

        Position of the stream to be selected from the input file (zero-based). Must not be set in combination with selectionMode 'AUTO', defaults to 0 for any other selectionMode.

        :return: The position of this StreamInput.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        # type: (int) -> None
        """Sets the position of this StreamInput.

        Position of the stream to be selected from the input file (zero-based). Must not be set in combination with selectionMode 'AUTO', defaults to 0 for any other selectionMode.

        :param position: The position of this StreamInput.
        :type: int
        """

        if position is not None:
            if position is not None and position < 0:
                raise ValueError("Invalid value for `position`, must be a value greater than or equal to `0`")
            if not isinstance(position, int):
                raise TypeError("Invalid type for `position`, type has to be `int`")

        self._position = position

    @property
    def input_stream_id(self):
        # type: () -> string_types
        """Gets the input_stream_id of this StreamInput.

        Set this property instead of all others to reference an InputStream resource (e.g. an Ingest-, Trimming- or ConcatenationInputStream)

        :return: The input_stream_id of this StreamInput.
        :rtype: string_types
        """
        return self._input_stream_id

    @input_stream_id.setter
    def input_stream_id(self, input_stream_id):
        # type: (string_types) -> None
        """Sets the input_stream_id of this StreamInput.

        Set this property instead of all others to reference an InputStream resource (e.g. an Ingest-, Trimming- or ConcatenationInputStream)

        :param input_stream_id: The input_stream_id of this StreamInput.
        :type: string_types
        """

        if input_stream_id is not None:
            if not isinstance(input_stream_id, string_types):
                raise TypeError("Invalid type for `input_stream_id`, type has to be `string_types`")

        self._input_stream_id = input_stream_id

    @property
    def analysis_details(self):
        # type: () -> EncodingStreamInputDetails
        """Gets the analysis_details of this StreamInput.

        Input analysis details  This property is populated after the encoding has finished 

        :return: The analysis_details of this StreamInput.
        :rtype: EncodingStreamInputDetails
        """
        return self._analysis_details

    @analysis_details.setter
    def analysis_details(self, analysis_details):
        # type: (EncodingStreamInputDetails) -> None
        """Sets the analysis_details of this StreamInput.

        Input analysis details  This property is populated after the encoding has finished 

        :param analysis_details: The analysis_details of this StreamInput.
        :type: EncodingStreamInputDetails
        """

        if analysis_details is not None:
            if not isinstance(analysis_details, EncodingStreamInputDetails):
                raise TypeError("Invalid type for `analysis_details`, type has to be `EncodingStreamInputDetails`")

        self._analysis_details = analysis_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
